/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
   \\    /   O peration     |
    \\  /    A nd           | Copyright (C) 1991-2005 OpenCFD Ltd.
     \\/     M anipulation  |
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
    Free Software Foundation; either version 2 of the License, or (at your
    option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM; if not, write to the Free Software Foundation,
    Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Class
    kOmegaBSL

Description
    Menter k-omega SST turbulence model.

SourceFiles
    kOmegaBSL.C
    kOmegaBSLCorrect.C

\*---------------------------------------------------------------------------*/

#ifndef kOmegaBSL_H
#define kOmegaBSL_H

#include "turbulenceModelOmega.H"
#include "wallDist.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{
namespace turbulenceModels
{

/*---------------------------------------------------------------------------*\
                           Class kOmegaBSL Declaration
\*---------------------------------------------------------------------------*/

class kOmegaBSL
:
    public turbulenceModel
{
    // Private data

        dimensionedScalar Cmu;
        dimensionedScalar C1_om;
        dimensionedScalar C1_eps;
        dimensionedScalar C2_eps;
        dimensionedScalar C2_om;
        dimensionedScalar alphaEps;
        dimensionedScalar alphaOmega;
        dimensionedScalar alphaKEps;
        dimensionedScalar alphaKOmega;

        volScalarField k_;
        volScalarField omega_;

        wallDist y_;

        volScalarField nut_;

        volScalarField alpha;
        volScalarField alphaK;


public:

    //- Runtime type information
    TypeName("kOmegaBSL");


    // Constructors

        //- from components
        kOmegaBSL
        (
            const volVectorField& U,
            const surfaceScalarField& phi,
            transportModel& transport
        );


    // Destructor

        ~kOmegaBSL(){}


    // Member Functions

        tmp<volScalarField> nut() const
        {
            return nut_;
        }

        //- Return the effective diffusivity for k
        tmp<volScalarField> DkEff() const
        {
            return tmp<volScalarField> 
            (
	     new volScalarField("DkEff", alphaK*nut_ + nu())
            );
        }

        //- Return the effective diffusivity for omega
        tmp<volScalarField> DomegaEff() const
        {
            return tmp<volScalarField>
            (
            new volScalarField("DomegaEff", alpha*nut_ + nu())
            );
        }

        tmp<volScalarField> k() const
        {
            return k_;
        }

        tmp<volScalarField> omega() const
        {
            return omega_;
        }

        tmp<volTensorField> R() const;

        tmp<fvVectorMatrix> divR(volVectorField& U) const;

        void correct();

        //- Read turbulenceProperties dictionary
        bool read();
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace turbulenceModels
} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
